==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/RadialLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredRadialSeriesDescriptionMetadata } from "./AnchoredRadialSeriesDescriptionMetadata";
import { RadialLineSeriesDescription } from "./RadialLineSeriesDescription";
/**
 * @hidden
 */
export let RadialLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RadialLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RadialLineSeriesDescriptionMetadata.a == null) {
                RadialLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RadialLineSeriesDescriptionMetadata.c(RadialLineSeriesDescriptionMetadata.a);
            }
            if (a.j(RadialLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(RadialLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            AnchoredRadialSeriesDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            RadialLineSeriesDescriptionMetadata.b(a);
            a.aa("RadialLineSeries", () => new RadialLineSeriesDescription());
            a.z("RadialLineSeries", RadialLineSeriesDescriptionMetadata.a);
        }
    }
    RadialLineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(RadialLineSeriesDescriptionMetadata, 'RadialLineSeriesDescriptionMetadata');
    RadialLineSeriesDescriptionMetadata.a = null;
    return RadialLineSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/RadialLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredRadialSeriesDescriptionMetadata } from "./AnchoredRadialSeriesDescriptionMetadata";
import { RadialLineSeriesDescription } from "./RadialLineSeriesDescription";
/**
 * @hidden
 */
export let RadialLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RadialLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RadialLineSeriesDescriptionMetadata.a == null) {
                RadialLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RadialLineSeriesDescriptionMetadata.c(RadialLineSeriesDescriptionMetadata.a);
            }
            if (a.k(RadialLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(RadialLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            AnchoredRadialSeriesDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            RadialLineSeriesDescriptionMetadata.b(a);
            a.ac("RadialLineSeries", () => new RadialLineSeriesDescription());
            a.ab("RadialLineSeries", RadialLineSeriesDescriptionMetadata.a);
        }
    }
    RadialLineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(RadialLineSeriesDescriptionMetadata, 'RadialLineSeriesDescriptionMetadata');
    RadialLineSeriesDescriptionMetadata.a = null;
    return RadialLineSeriesDescriptionMetadata;
})();
